CSbj: Current Status Data Buckley-James Estimator For Linear...

View source: R/CSbj.R

CSbjR Documentation

Current Status Data Buckley-James Estimator For Linear Regression Models

Description

In an AFT regression model, when the reponses are current status censored (observe yi either > ti or <= ti), we may still estimate the regression coefficients by the Buckley-James (extension from right censored case). We assume the inspection time ti have a larger support to cover the support of error epsilon, which is assumed iid.

Usage

CSbj(x, delta, Itime, maxiter = 99, error = 0.0001) 

Arguments

x

Design matrix. N rows p columns.

delta

Either 0 or 1. I[yi <= Itimei]. Length N. yi = beta xi + ei

Itime

The inspection times. Length N.

maxiter

Default to 99. Control the iteration.

error

Default to 0.0001. Control the iteration.

Details

This function is an implementation of the Buckley-James estimator for the regression parameter beta in the AFT regression model when the responses, yi, are current status censored. Similar to the Binary Choice model in econometrics where all the inspection times are fixed at zero. I wrote an S-plus function for the binary choice model (name bibj). It is easily adapted to the current status situation, and this is the function. The AFT model we considered here has an intercept term. But we try to estimate the regression parameter beta, without the intercept term first. The estimator of the intercept can be obtained (if needed) as the mean of the iid errors/residuals after we got the estimator of the slope parameter beta.

This function depends on the functions monotone from package monotone and lsfit from the basic stats package.

At this point, we do not have a good estimate for the variance for the Buckley-James estimators. Bootstrap is one method one can try.

Value

It returns a list containing

est

The Buckley-James estimator of the regression coefficients.

iterN

Number of iterations done.

distFx

Locations of the jumps of final estimator of the error distribution.

distFy

Probabilities of the final estimator of the error distribution at jump locations. Mean of this error distribution is the intercept term estimator of the regression model.

Author(s)

Mai Zhou <maizhou@gmail.com>.

References

Zhou, M. (2026). Empirical Likelihood Method in Survival Analysis 2nd Edition Chapman & Hall/CRC

Wang, W., and Zhou, M. (1995). Iterative least squares estimator of binary choice models: a semi-parametric approach. Tech. Report, University of Kentucky. https://www.ms.uky.edu/~mai/research/eco5wz.pdf

Buckley, J. J., and James, I. R. (1979). Linear regression with censored data. Biometrika 66, 429–436.

Examples

 
y <- c(10, 209, 273, 279, 324, 391, 566, 785)
x <- c(21, 38, 39, 51, 77, 185, 240, 289, 524)

emplikCS documentation built on June 21, 2026, 1:07 a.m.

Related to CSbj in emplikCS...