| L2S | R Documentation |
Given current status data (two vectors of length n): one vector of inspection times, the other vector = I[Yi <= ti]. We assume the input is ordered according to itime. Convert the same data into short format. Useful when there are a lot of tied inspection times. (saves space).
L2S(itime, delta)
itime |
The inspection times. Length n. |
delta |
Either 0 or 1. I[yi <= itimei]. Length n. |
Same data set of 850 cases Hepatitis A tests from Bulgaria recorded
in long format hepABulg in the R package csci compare to
the short format
hepatitisA in the R package curstatCI.
This function (and the sister function S2L)
can be used to convert between the short and long format.
It returns a list containing
Sitime |
The ordered inspection times. Short format. Tied itimes removed. |
fi |
Number of delta's=1, with identical itime ti. |
ni |
Number of itimes tied at ti. |
Mai Zhou <maizhou@gmail.com>.
Zhou, M. (2026). Empirical Likelihood Method in Survival Analysis 2nd Edition Chapman & Hall/CRC
y <- c(10, 209, 273, 279, 324, 391, 566, 785)
x <- c(21, 38, 39, 51, 77, 185, 240, 289, 524)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.