| el.CS.mean | R Documentation |
Given n current status data, we may estimate the CDF F(t) by NPMLE
(e.g. by the isotNEW2() function in this package).
Based on the NPMLE \hat F_n(t) we can estimate the mean mu(F).
This function, el.CS.mean, uses empirical likelihood to test the hypothesis that mu(F)
equal to a given value(mu): i.e. H0: mu(F) = mu.
Empirical likelihood ratio test returns the Wilks statistics, -2LLR. The -2 log likelihood ratio under H0 is asymptotically chi square DF=1 distributed. See reference below.
el.CS.mean(mu, Itime, delta, Pfun)
mu |
The hypothesized mean value. |
Itime |
The inspection times, a vector of length n. |
delta |
Either 0 or 1. I[yi <= ti]. length n. |
Pfun |
A given function, |
This function tests the null hypothesis that mu(F) = mu versus not equal. We assume the data given is current status censored data.
The definition of the mean, mu(F) is
\mu(F) = \int_0^M [1- F(t)] d \Psi(t)
and its estimator based on (\delta_i, t_i)
or \hat F_n is (assume \min(t_i) =0 or t_{(1)} =0)
{\mu(\hat F_n )} = \sum_{i=1}^n [1-\hat F_n(t_{(i)})] \Delta \Psi(t_{(i)})~,
where \Psi (t) is a given function and
\Delta \Psi(t_{(i)})= \Psi (t_{(i+1)}) - \Psi(t_{(i)}) .
If \Psi(t) =t in the above, then this
is the ordinary mean (assuming F(t) has support (0, M) ).
The NPMLE \hat F_n(t) is convergent at cubic root n speed, but the mean estimator is
convergent at ordinary root n speed. The -2LLR has chi square DF=1 null distribution asymptotically.
It goes without saying that we assume the NPMLE mu(hat F) has finite asymptotic variance (when normalized by root n).
It returns a list containing
"-2LLR" |
The Wilks statistics of the EL test, has approximate chi SQ DF=1 distribution under null hypothesis. |
Mai Zhou <maizhou@gmail.com>.
Zhou, M. (2026). Empirical Likelihood Method in Survival Analysis 2nd Edition Chapman & Hall/CRC
Huang, J. and Wellner, J. (1995). Asymptotic normality of the NPMLE of linear functionals for interval censored data, case 1 Statistica Neerlandica 49, 2, 153–163.
Sun, J. (2006). The Statistical Analysis of Interval-Censored Failure Time Data Springer, New York.
N <- 300
set.seed(12345)
itime <- sort(c(rexp(N-1), 0.5) ) #### inspection times
Stime <- rexp(N) #### survival times
delta <- as.numeric(Stime <= itime) #### current status censoring
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.