| rubella | R Documentation |
A dataset on the prevalence of rubella in 230 Austrian males older than three months for whom the exact date of birth was known. Each individual was tested at the Institute of Virology, Vienna during the period March 1 to 25, 1988 for immunization against Rubella.
This data set is taken from the package "curstatCI" version 0.1.0. Unfortunately that package is no longer on active list of CRAN. We need the data set for several examples, so we copy the data set here.
This data set is in the short format. You can convert from short to long format by using code S2L().
data(rubella)
A data frame with 225 rows and three variables:
Age of the individual at the time of testing for immunization
Number of individuals of age t that are immune for Rubella
Total number of individuals of age t
Keiding, N., Begtrup, K., Scheike, T., and Hasibeder, G. (1996). Estimation from current status data in continuous time. Lifetime Data Anal., 2:119-129.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.